@@ -3,7 +3,7 @@
 """
 Directory : orpyste
 Name      : reader
-Version   : 2013.05
+Version   : 2013.09
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
 
@@ -23,9 +23,9 @@ from orpyste import model
 
 class ReaderError(ValueError):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 Base class for errors in the ``reader`` module of the package ``orpyste``.
     """
@@ -38,9 +38,9 @@ Base class for errors in the ``reader`` module of the package ``orpyste``.
 
 def DEFAULT_IS_BLOCK_NAME(text):
     """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This function tests that the string ``text`` is a legal name for a ¨peuf block.
     """
@@ -56,8 +56,23 @@ This function tests that the string ``text`` is a legal name for a ¨peuf block.
 
 class Build(model.parser.Skeleton):
     """
------------------
+:::::::::::::::::
 Small description
+:::::::::::::::::
+
+-----------------
+?? ?? ?? ?? ?? ??
+-----------------
+
+
+
+
+
+
+
+
+-----------------
+?? ?? ?? ?? ?? ??
 -----------------
 
 Suppose that you have the following ``orpyste`` file (sorry for the lake of
@@ -239,9 +254,9 @@ python::
     }
 
 
--------------
+:::::::::::::
 The arguments
--------------
+:::::::::::::
 
 This class uses the following variables.
 
@@ -359,9 +374,9 @@ This class uses the following variables.
 
     def build(self):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 Each time you make an instance of ``Reader``this method is called so as to
 automatically build the ``(Number line, Content)`` and the simple ``Content``
@@ -423,7 +438,7 @@ of the content of the file or of the value of the attribut ``content``.
         )
 
 # The only content dictionary.
-        self.dict = self.__flattenDict(self.dictNbLine)
+        self.dict = self.__flatDict(self.dictNbLine)
 
     def __analyse(
         self,
@@ -433,9 +448,9 @@ of the content of the file or of the value of the attribut ``content``.
         inBlock = False
     ):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This method does all the ugly job for analysing the ``orpyste`` file so as to
 build the ``(number line, content)`` dictionary.
@@ -456,7 +471,15 @@ build the ``(number line, content)`` dictionary.
             else:
                 popNewLine = True
 
-            storeThisLine = (mode == "block" or not oneLine.strip() == '')
+# We have to take care of empty lines starting the file when we use the block
+# mode !
+            isLineEmpty = (oneLine.strip() == '')
+
+            if mode == "block":
+                storeThisLine = (not isLineEmpty or answer)
+
+            else:
+                storeThisLine = not isLineEmpty
 
 
 # -- COMMENT ON SEVERAL LINES -- #
@@ -673,21 +696,24 @@ build the ``(number line, content)`` dictionary.
 # -- FLAT DICTIONARY -- #
 # --------------------- #
 
-    def __flattenDict(self, oneDict):
+    def __flatDict(self, oneDict):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This method transforms the ``(Number line, Content)`` dictionary to a simple
 ``Content`` dictionary.
         """
+        if oneDict == (None, ''):
+            return {}
+
         flatDict = collections.OrderedDict()
 
         for oneKey, oneValue in oneDict.items():
             if isinstance(oneValue, dict) \
             or isinstance(oneValue, collections.OrderedDict):
-                oneValue = self.__flattenDict(oneValue)
+                oneValue = self.__flatDict(oneValue)
 
             elif isinstance(oneValue, tuple):
                 oneValue = oneValue[1]
@@ -704,11 +730,11 @@ This method transforms the ``(Number line, Content)`` dictionary to a simple
 # -- EQUAL (PLUS) LIKE MODE -- #
 # ---------------------------- #
 
-    def __findOnSep(self, text, sep):
+    def __findOneSep(self, text, sep):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This methods returns the position in ``text`` of the first string ``sep`` which
 is not preceded by a backslash.
@@ -725,11 +751,11 @@ If there is no matchning, the value ``(-1)`` is returned.
 
     def __findSep(self, text):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
-This method returns the possible position of the first not esacaped separator
+This method returns the possible position of the first not escaped separator
 (this is for for the the modes ``"equal"``, ``"equal+"``, ``"keyval"`` and
 ``"keyval+"``). Indeed, the method returns ``(iKey, iVal, sep)`` where each
 parameter has the following meaning.
@@ -745,7 +771,7 @@ parameter has the following meaning.
         sep  = None
 
         for oneSep in self.sep:
-            j = self.__findOnSep(
+            j = self.__findOneSep(
                 text = text,
                 sep  = oneSep
             )
@@ -763,9 +789,9 @@ parameter has the following meaning.
         escapeKeyval = False
     ):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This methods simply removes backslashes that escapes double points.
 
@@ -792,9 +818,9 @@ By default, ``escapeKeyval = False``.
         mode
     ):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This methods manages the storing for values for the modes ``"equal"``,
 ``"equal+"``, ``"keyval"`` and ``"keyval+"``.
@@ -821,9 +847,9 @@ This methods manages the storing for values for the modes ``"equal"``,
 
     def __sendError(self, message):
         """
------------------
+:::::::::::::::::
 Small description
------------------
+:::::::::::::::::
 
 This method simply eases the raising of errors by adding infos about the file or
 the string content analysed.
